@@ -9,24 +9,24 @@
 #include "ktitlewidget.h"
 
 #include <QApplication>
-#include <QTimer>
-#include <QMouseEvent>
 #include <QFrame>
+#include <QIcon>
 #include <QLabel>
 #include <QLayout>
-#include <QTextDocument>
-#include <QIcon>
+#include <QMouseEvent>
 #include <QStyle>
+#include <QTextDocument>
+#include <QTimer>
 
-class Q_DECL_HIDDEN KTitleWidget::Private
+class KTitleWidgetPrivate
 {
 public:
-    Private(KTitleWidget *parent)
+    KTitleWidgetPrivate(KTitleWidget *parent)
         : q(parent)
-          // use Left so updateIconAlignment(ImageRight) as called by constructor triggers the default layout
+        // use Left so updateIconAlignment(ImageRight) as called by constructor triggers the default layout
         , iconAlignment(KTitleWidget::ImageLeft)
         , autoHideTimeout(0)
-        , messageType(InfoMessage)
+        , messageType(KTitleWidget::InfoMessage)
     {
     }
 
@@ -35,13 +35,13 @@ public:
         qreal factor;
         switch (level) {
         case 1:
-            factor = 1.50;
+            factor = 1.35;
             break;
         case 2:
-            factor = 1.30;
+            factor = 1.20;
             break;
         case 3:
-            factor = 1.20;
+            factor = 1.15;
             break;
         case 4:
             factor = 1.10;
@@ -49,7 +49,7 @@ public:
         default:
             factor = 1;
         }
-        const int fontSize = qRound(QApplication::font().pointSize() * factor);
+        const double fontSize = QApplication::font().pointSize() * factor;
         return QStringLiteral("QLabel { font-size: %1pt; color: %2 }").arg(QString::number(fontSize), q->palette().color(QPalette::WindowText).name());
     }
 
@@ -57,16 +57,17 @@ public:
     {
         QString styleSheet;
         switch (messageType) {
-        //FIXME: we need the usability color styles to implement different
+        // FIXME: we need the usability color styles to implement different
         //       yet palette appropriate colours for the different use cases!
         //       also .. should we include an icon here,
         //       perhaps using the imageLabel?
-        case InfoMessage:
-        case WarningMessage:
-        case ErrorMessage:
-            styleSheet = QStringLiteral("QLabel { color: palette(%1); background: palette(%2); }").arg(q->palette().color(QPalette::HighlightedText).name(), q->palette().color(QPalette::Highlight).name());
+        case KTitleWidget::InfoMessage:
+        case KTitleWidget::WarningMessage:
+        case KTitleWidget::ErrorMessage:
+            styleSheet = QStringLiteral("QLabel { color: palette(%1); background: palette(%2); }")
+                             .arg(q->palette().color(QPalette::HighlightedText).name(), q->palette().color(QPalette::Highlight).name());
             break;
-        case PlainMessage:
+        case KTitleWidget::PlainMessage:
         default:
             break;
         }
@@ -85,7 +86,7 @@ public:
         headerLayout->removeWidget(commentLabel);
         headerLayout->removeWidget(imageLabel);
 
-        if (iconAlignment == ImageLeft) {
+        if (iconAlignment == KTitleWidget::ImageLeft) {
             // swap the text and image labels around
             headerLayout->addWidget(imageLabel, 0, 0, 2, 1);
             headerLayout->addWidget(textLabel, 0, 1);
@@ -117,7 +118,7 @@ public:
     QSize iconSize;
     KTitleWidget::ImageAlignment iconAlignment;
     int autoHideTimeout;
-    MessageType messageType;
+    KTitleWidget::MessageType messageType;
 
     /**
      * @brief Get the icon name from the icon type
@@ -126,13 +127,13 @@ public:
      */
     QString iconTypeToIconName(KTitleWidget::MessageType type);
 
-    void _k_timeoutFinished()
+    void timeoutFinished()
     {
         q->setVisible(false);
     }
 };
 
-QString KTitleWidget::Private::iconTypeToIconName(KTitleWidget::MessageType type)
+QString KTitleWidgetPrivate::iconTypeToIconName(KTitleWidget::MessageType type)
 {
     switch (type) {
     case KTitleWidget::InfoMessage:
@@ -149,19 +150,20 @@ QString KTitleWidget::Private::iconTypeToIconName(KTitleWidget::MessageType type
 }
 
 KTitleWidget::KTitleWidget(QWidget *parent)
-    : QWidget(parent),
-      d(new Private(this))
+    : QWidget(parent)
+    , d(new KTitleWidgetPrivate(this))
 {
     QFrame *titleFrame = new QFrame(this);
     titleFrame->setAutoFillBackground(true);
     titleFrame->setFrameShape(QFrame::StyledPanel);
     titleFrame->setFrameShadow(QFrame::Plain);
-    titleFrame->setBackgroundRole(QPalette::Base);
+    titleFrame->setBackgroundRole(QPalette::Window);
     titleFrame->setContentsMargins(0, 0, 0, 0);
 
     // default image / text part start
     d->headerLayout = new QGridLayout(titleFrame);
     d->headerLayout->setContentsMargins(0, 0, 0, 0);
+    d->headerLayout->setSizeConstraint(QLayout::SetFixedSize);
 
     d->textLabel = new QLabel(titleFrame);
     d->textLabel->setVisible(false);
@@ -182,19 +184,14 @@ KTitleWidget::KTitleWidget(QWidget *parent)
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(titleFrame);
     mainLayout->setContentsMargins(0, 0, 0, 0);
-    setLayout(mainLayout);
 }
 
-KTitleWidget::~KTitleWidget()
-{
-    delete d;
-}
+KTitleWidget::~KTitleWidget() = default;
 
 bool KTitleWidget::eventFilter(QObject *object, QEvent *event)
 {
     // Hide message label on click
-    if (d->autoHideTimeout > 0 &&
-            event->type() == QEvent::MouseButtonPress) {
+    if (d->autoHideTimeout > 0 && event->type() == QEvent::MouseButtonPress) {
         QMouseEvent *mouseEvent = static_cast<QMouseEvent *>(event);
         if (mouseEvent && mouseEvent->button() == Qt::LeftButton) {
             setVisible(false);
@@ -220,17 +217,6 @@ QString KTitleWidget::comment() const
     return d->commentLabel->text();
 }
 
-#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 72)
-const QPixmap *KTitleWidget::pixmap() const
-{
-QT_WARNING_PUSH
-QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
-QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
-    return d->imageLabel->pixmap();
-QT_WARNING_POP
-}
-#endif
-
 QIcon KTitleWidget::icon() const
 {
     return d->icon;
@@ -253,8 +239,7 @@ void KTitleWidget::setBuddy(QWidget *buddy)
 void KTitleWidget::changeEvent(QEvent *e)
 {
     QWidget::changeEvent(e);
-    if (e->type() == QEvent::PaletteChange || e->type() == QEvent::FontChange
-                                           || e->type() == QEvent::ApplicationFontChange) {
+    if (e->type() == QEvent::PaletteChange || e->type() == QEvent::FontChange || e->type() == QEvent::ApplicationFontChange) {
         d->textLabel->setStyleSheet(d->textStyleSheet());
         d->commentLabel->setStyleSheet(d->commentStyleSheet());
         d->updatePixmap();
@@ -305,7 +290,7 @@ void KTitleWidget::setComment(const QString &comment, MessageType type)
 {
     d->commentLabel->setVisible(!comment.isNull());
 
-    //TODO: should we override the current icon with the corresponding MessageType icon?
+    // TODO: should we override the current icon with the corresponding MessageType icon?
     d->messageType = type;
     d->commentLabel->setStyleSheet(d->commentStyleSheet());
     d->commentLabel->setText(comment);
@@ -323,7 +308,7 @@ void KTitleWidget::setIcon(const QIcon &icon, KTitleWidget::ImageAlignment align
     d->updatePixmap();
 }
 
-void KTitleWidget::setIconSize(const QSize& iconSize)
+void KTitleWidget::setIconSize(const QSize &iconSize)
 {
     if (d->iconSize == iconSize) {
         return;
@@ -338,42 +323,6 @@ void KTitleWidget::setIconSize(const QSize& iconSize)
     }
 }
 
-
-#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 72)
-void KTitleWidget::setPixmap(const QPixmap &pixmap, ImageAlignment alignment)
-{
-    d->icon = QIcon(pixmap);
-    d->iconSize = pixmap.size();
-
-    d->imageLabel->setVisible(!d->icon.isNull());
-
-    d->updateIconAlignment(alignment);
-
-    d->updatePixmap();
-}
-#endif
-
-#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 63)
-void KTitleWidget::setPixmap(const QString &icon, ImageAlignment alignment)
-{
-    setIcon(QIcon::fromTheme(icon), alignment);
-}
-#endif
-
-#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 63)
-void KTitleWidget::setPixmap(const QIcon &icon, ImageAlignment alignment)
-{
-    setIcon(icon, alignment);
-}
-#endif
-
-#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 72)
-void KTitleWidget::setPixmap(MessageType type, ImageAlignment alignment)
-{
-    setIcon(type, alignment);
-}
-#endif
-
 void KTitleWidget::setIcon(MessageType type, ImageAlignment alignment)
 {
     setIcon(QIcon::fromTheme(d->iconTypeToIconName(type)), alignment);
@@ -399,7 +348,9 @@ void KTitleWidget::showEvent(QShowEvent *event)
 {
     Q_UNUSED(event)
     if (d->autoHideTimeout > 0) {
-        QTimer::singleShot(d->autoHideTimeout, this, [this] { d->_k_timeoutFinished(); });
+        QTimer::singleShot(d->autoHideTimeout, this, [this] {
+            d->timeoutFinished();
+        });
     }
 }
 
